==> haskell-hw-hspec-hedgehog-0.1.1.1-112-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hw-hspec-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hw-hspec-hedgehog
version:              0.1.1.1
visibility:           public
id:                   hw-hspec-hedgehog-0.1.1.1-DbjDjrC4F4bKt2NySDhY3f
key:                  hw-hspec-hedgehog-0.1.1.1-DbjDjrC4F4bKt2NySDhY3f
license:              BSD-3-Clause
copyright:            2017-2021 John Ky
maintainer:           newhoggy@gmail.com
author:               John Ky
homepage:             https://github.com/haskell-works/hw-hspec-hedgehog#readme
synopsis:             Interoperability between hspec and hedgehog
description:          Interoperability between hspec and hedgehog.
category:             Test
abi:                  c45acb288ef2ac7da20ce59b7e3d60c9
exposed:              True
exposed-modules:      HaskellWorks.Hspec.Hedgehog
hidden-modules:       Paths_hw_hspec_hedgehog
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hw-hspec-hedgehog-0.1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hw-hspec-hedgehog-0.1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hw-hspec-hedgehog-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hw-hspec-hedgehog
hs-libraries:         HShw-hspec-hedgehog-0.1.1.1-DbjDjrC4F4bKt2NySDhY3f
depends:
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA base-4.17.2.1
    call-stack-0.4.0-AAQ0PbHtRxA9hkeprsdCAo
    hedgehog-1.3-Phdxv42jAc1sEB26Wgu2C
    hspec-2.10.9-LFxAr7Wn9ofEhyFifx4TyA transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hw-hspec-hedgehog/html/hw-hspec-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-hw-hspec-hedgehog/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hw-hspec-hedgehog-0.1.1.1-113-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hw-hspec-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hw-hspec-hedgehog
version:              0.1.1.1
visibility:           public
id:                   hw-hspec-hedgehog-0.1.1.1-1aE8v09aWuzHNhR6SyUd93
key:                  hw-hspec-hedgehog-0.1.1.1-1aE8v09aWuzHNhR6SyUd93
license:              BSD-3-Clause
copyright:            2017-2021 John Ky
maintainer:           newhoggy@gmail.com
author:               John Ky
homepage:             https://github.com/haskell-works/hw-hspec-hedgehog#readme
synopsis:             Interoperability between hspec and hedgehog
description:          Interoperability between hspec and hedgehog.
category:             Test
abi:                  509e5ba3dc48eb77a2d56081f4a285c9
exposed:              True
exposed-modules:      HaskellWorks.Hspec.Hedgehog
hidden-modules:       Paths_hw_hspec_hedgehog
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hw-hspec-hedgehog-0.1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hw-hspec-hedgehog-0.1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hw-hspec-hedgehog-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hw-hspec-hedgehog
hs-libraries:         HShw-hspec-hedgehog-0.1.1.1-1aE8v09aWuzHNhR6SyUd93
depends:
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA base-4.17.2.1
    call-stack-0.4.0-AAQ0PbHtRxA9hkeprsdCAo
    hedgehog-1.3-5IRcuyn0LwP7K0IcKhEqKJ
    hspec-2.10.9-EMMSF8OTUYm2iE3YzvfAMI transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hw-hspec-hedgehog/html/hw-hspec-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-hw-hspec-hedgehog/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
